@@ -1,12 +1,12 @@
-#[cfg(any(target_os = "emscripten", target_os = "wasi", target_os = "redox"))]
+#[cfg(any(target_os = "emscripten", target_os = "redox", target_os = "wasi"))]
 fn main() {
     unimplemented!()
 }
 
-#[cfg(not(any(target_os = "emscripten", target_os = "wasi", target_os = "redox")))]
+#[cfg(not(any(target_os = "emscripten", target_os = "redox", target_os = "wasi")))]
 use criterion::{criterion_group, criterion_main};
 
-#[cfg(not(any(target_os = "emscripten", target_os = "wasi", target_os = "redox")))]
+#[cfg(not(any(target_os = "emscripten", target_os = "redox", target_os = "wasi")))]
 mod suite {
     use criterion::Criterion;
 
@@ -116,7 +116,7 @@ mod suite {
     }
 }
 
-#[cfg(not(any(target_os = "emscripten", target_os = "wasi", target_os = "redox")))]
+#[cfg(not(any(target_os = "emscripten", target_os = "redox", target_os = "wasi")))]
 criterion_group!(
     benches,
     suite::simple_statat,
@@ -128,5 +128,5 @@ criterion_group!(
     suite::simple_getpid,
     suite::simple_getpid_libc
 );
-#[cfg(not(any(target_os = "emscripten", target_os = "wasi", target_os = "redox")))]
+#[cfg(not(any(target_os = "emscripten", target_os = "redox", target_os = "wasi")))]
 criterion_main!(benches);
