@@ -1,4 +1,7 @@
-use crate::{io, path::DecInt};
+use crate::io;
+use crate::path::DecInt;
+use std::borrow::Cow;
+use std::ffi::{CStr, CString, OsStr, OsString};
 #[cfg(target_os = "hermit")]
 use std::os::hermit::ext::ffi::{OsStrExt, OsStringExt};
 #[cfg(unix)]
@@ -7,12 +10,8 @@ use std::os::unix::ffi::{OsStrExt, OsStringExt};
 use std::os::vxworks::ext::ffi::{OsStrExt, OsStringExt};
 #[cfg(target_os = "wasi")]
 use std::os::wasi::ffi::{OsStrExt, OsStringExt};
-use std::{
-    borrow::Cow,
-    ffi::{CStr, CString, OsStr, OsString},
-    path::{Component, Components, Iter, Path, PathBuf},
-    str,
-};
+use std::path::{Component, Components, Iter, Path, PathBuf};
+use std::str;
 
 /// A trait for passing path arguments.
 ///
@@ -22,7 +21,8 @@ use std::{
 /// # Example
 ///
 /// ```rust
-/// use posish::{io, path::Arg};
+/// use posish::io;
+/// use posish::path::Arg;
 /// use std::ffi::CStr;
 ///
 /// pub fn touch<P: Arg>(path: P) -> io::Result<()> {
@@ -1250,7 +1250,7 @@ where
     if bytes.len() >= SIZE {
         return with_c_str_slow_path(bytes, f);
     }
-    let mut buffer: [u8; SIZE] = [0u8; SIZE];
+    let mut buffer: [u8; SIZE] = [0_u8; SIZE];
     // Copy the bytes in; the buffer already has zeros for the trailing NUL.
     buffer[..bytes.len()].copy_from_slice(bytes);
     f(CStr::from_bytes_with_nul(&buffer[..=bytes.len()]).map_err(|_cstr_err| io::Error::INVAL)?)
