@@ -1,5 +1,6 @@
 #![cfg(any(target_os = "android", target_os = "linux"))]
 
+use io_lifetimes::AsFd;
 use posish::io::epoll::{self, Epoll};
 use posish::io::{ioctl_fionbio, read, write};
 use posish::net::{
@@ -31,7 +32,7 @@ fn server(ready: Arc<(Mutex<u16>, Condvar)>) {
 
     let epoll = Epoll::new(epoll::CreateFlags::CLOEXEC, epoll::Owning::new()).unwrap();
 
-    let raw_listen_sock = listen_sock.as_raw_fd();
+    let raw_listen_sock = listen_sock.as_fd().as_raw_fd();
     epoll.add(listen_sock, epoll::EventFlags::IN).unwrap();
 
     let mut event_list = epoll::EventVec::with_capacity(4);
@@ -80,11 +81,17 @@ fn test_epoll() {
     let ready = Arc::new((Mutex::new(0_u16), Condvar::new()));
     let ready_clone = Arc::clone(&ready);
 
-    let _server = thread::spawn(move || {
-        server(ready);
-    });
-    let client = thread::spawn(move || {
-        client(ready_clone);
-    });
+    let _server = thread::Builder::new()
+        .name("server".to_string())
+        .spawn(move || {
+            server(ready);
+        })
+        .unwrap();
+    let client = thread::Builder::new()
+        .name("client".to_string())
+        .spawn(move || {
+            client(ready_clone);
+        })
+        .unwrap();
     client.join().unwrap();
 }
